@@ -30,6 +30,25 @@ from .placedorder import PlacedOrdersContainer
 from .watcher import Watcher
 
 
+# # 🥭 EventQueue protocol
+#
+# The `EventQueue` protocol just says the object has a property `accounts_to_crank` that returns a `Sequence` of `PublicKey`s.
+#
+# This is to share the interface between a `SerumEventQueue` and a `PerpEventQueue` for cranking, when the
+# underlying objects are really quite different.
+#
+class EventQueue(typing.Protocol):
+    @property
+    def accounts_to_crank(self) -> typing.Sequence[PublicKey]:
+        raise NotImplementedError("EventQueue.accounts_to_crank is not implemented on the Protocol.")
+
+
+class NullEventQueue:
+    @property
+    def accounts_to_crank(self) -> typing.Sequence[PublicKey]:
+        return []
+
+
 # # 🥭 ModelState class
 #
 # Provides simple access to the latest state of market and account data.
@@ -43,7 +62,8 @@ class ModelState:
                  price_watcher: Watcher[Price],
                  placed_orders_container_watcher: Watcher[PlacedOrdersContainer],
                  inventory_watcher: Watcher[Inventory],
-                 orderbook: Watcher[OrderBook]
+                 orderbook: Watcher[OrderBook],
+                 event_queue: Watcher[EventQueue]
                  ) -> None:
         self._logger: logging.Logger = logging.getLogger(self.__class__.__name__)
         self.order_owner: PublicKey = order_owner
@@ -55,6 +75,7 @@ class ModelState:
             PlacedOrdersContainer] = placed_orders_container_watcher
         self.inventory_watcher: Watcher[Inventory] = inventory_watcher
         self.orderbook_watcher: Watcher[OrderBook] = orderbook
+        self.event_queue_watcher: Watcher[EventQueue] = event_queue
 
         self.not_quoting: bool = False
         self.state: typing.Dict[str, typing.Any] = {}
@@ -105,6 +126,10 @@ class ModelState:
     def spread(self) -> Decimal:
         return self.orderbook.spread
 
+    @property
+    def accounts_to_crank(self) -> typing.Sequence[PublicKey]:
+        return self.event_queue_watcher.latest.accounts_to_crank
+
     def current_orders(self) -> typing.Sequence[Order]:
         self.orderbook
         all_orders = [*self.bids, *self.asks]
